==> haskell-regex-pcre-0.94.4-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-pcre
version: 0.94.4
id: regex-pcre-0.94.4-7gir13ra3piLxu9vBj0iCM
key: regex-pcre-0.94.4-7gir13ra3piLxu9vBj0iCM
license: BSD3
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
stability: Seems to work, passes a few tests
homepage: http://hackage.haskell.org/package/regex-pcre
package-url: http://code.haskell.org/regex-pcre/
synopsis: Replaces/Enhances Text.Regex
description:
    The PCRE backend to accompany regex-base, see www.pcre.org
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.Wrap Text.Regex.PCRE.String
    Text.Regex.PCRE.Sequence Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy
abi: 42c0f18450b0df79d9ed146132860374
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/regex-pcre-0.94.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/regex-pcre-0.94.4
data-dir: /usr/share/arm-linux-ghc-8.0.1/regex-pcre-0.94.4
hs-libraries: HSregex-pcre-0.94.4-7gir13ra3piLxu9vBj0iCM
extra-libraries:
    pcre
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
haddock-interfaces: /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html: /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-pcre-0.94.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-pcre
version: 0.94.4
id: regex-pcre-0.94.4-FoWT2VQCFeqKub0RjpiMo1
key: regex-pcre-0.94.4-FoWT2VQCFeqKub0RjpiMo1
license: BSD3
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
stability: Seems to work, passes a few tests
homepage: http://hackage.haskell.org/package/regex-pcre
package-url: http://code.haskell.org/regex-pcre/
synopsis: Replaces/Enhances Text.Regex
description:
    The PCRE backend to accompany regex-base, see www.pcre.org
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.Wrap Text.Regex.PCRE.String
    Text.Regex.PCRE.Sequence Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy
abi: ceffe741f34ed27fd1e47eb1f1a8b97a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/regex-pcre-0.94.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/regex-pcre-0.94.4
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/regex-pcre-0.94.4
hs-libraries: HSregex-pcre-0.94.4-FoWT2VQCFeqKub0RjpiMo1
extra-libraries:
    pcre
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    regex-base-0.93.2-AYjYAsBidAc8f5XNm9b2Aa
haddock-interfaces: /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html: /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
